========
Glossary
========

This glossary offers a list of terms and definitions to define a
vocabulary for OpenStack-related concepts.

C
~

.. glossary::

   Cross-Origin Resource Sharing (CORS)

      A mechanism that allows many resources (for example,
      fonts, JavaScript) on a web page to be requested from
      another domain outside the domain from which the resource
      originated. In particular, JavaScript's AJAX calls can use
      the XMLHttpRequest mechanism.
